@@ -25,11 +25,11 @@ Test::Aggregate - Aggregate C<*.t> tests to make them run faster.
 
 =head1 VERSION
 
-Version 0.370
+Version 0.372
 
 =cut
 
-our $VERSION = '0.370';
+our $VERSION = '0.372';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -247,6 +247,17 @@ problems.
 
 =back
 
+=cut
+
+sub new {
+    my $class = shift;
+    my $self = $class->SUPER::new(@_);
+    if ($self->{no_generate_plan}) {
+        croak "no_generate_plan is not supported in Test::Aggregate";
+    }
+    return $self;
+}
+
 =head2 C<run>
 
  $tests->run;
